Learn R Programming

CAISEr (version 0.3.3)

get_observations: Run an algorithm on a problem.

Description

Call algorithm routine for the solution of a problem instance

Usage

get_observations(algo, instance, n = 1)

Arguments

algo

a list object containing the definitions of the algorithm. See calc_nreps2() for details.

instance

a list object containing the definitions of the problem instance. See calc_nreps2() for details.

n

number of observations to generate.

Value

vector of observed performance values

See Also

calc_nreps2

Examples

Run this code
# NOT RUN {
algorithm <- list(FUN = "dummyalgo", alias = "myalgo",
                  distribution.fun = "rnorm",
                  distribution.pars = list(mean = 50, sd = 10))
instance <- list(FUN = "dummyinstance")
x <- get_observations(algorithm, instance, n = 1000)
hist(x)
# }

Run the code above in your browser using DataLab