powered by
Calculates the sample estimator of the (simple or percent) differences between the means of two algorithms on a given instance.
If `dif == "simple": estimates \(mu2 - mu1\),
If `dif == "perc": estimates \((mu2 - mu1) / mu1\),
calc_phi(x1, x2, dif)
vector of observations
type of difference to estimate ("simple" or "perc")
Estimated value of the statistic given in dif
dif
where \(mu1, mu2\) are the means of the populations that generated the sample vectors \(x1, x2\).
F. Campelo, F. Takahashi: Sample size estimation for power and accuracy in the experimental comparison of algorithms (submitted, 2017).
# NOT RUN { x1 <- rnorm(25, 3, 0.5) x2 <- runif(15, 4, 6) calc_phi(x1, x2, "simple") calc_phi(x1, x2, "perc") # }
Run the code above in your browser using DataLab