Learn R Programming

CAISEr (version 0.3.3)

se_param: Parametric standard errors

Description

Calculates the standard error of a given statistic using parametric formulas

Usage

se_param(x1, x2, dif, ...)

Arguments

x1

vector of observations

x2

vector of observations

dif

name of the difference for which the SE is desired. Accepts "simple" (simple differences) or "perc" (percent differences).

...

other parameters (used only for compatibility with calls to se_boot(), unused in this function)

Value

estimated standard error

References

  • E.C. Fieller: Some problems in interval estimation. Journal of the Royal Statistical Society. Series B (Methodological) 16(2), 175<U+2013>185 (1954)

  • V. Franz: Ratios: A short guide to confidence limits and proper use (2007). https://arxiv.org/pdf/0710.2024v1.pdf

  • D.C. Montgomery, C.G. Runger: Applied Statistics and Probability for Engineers, 6th ed. Wiley (2013)

  • F. Campelo, F. Takahashi: Sample size estimation for power and accuracy in the experimental comparison of algorithms (submitted, 2017).

Examples

Run this code
# NOT RUN {
# two vectors of normally distributed observations
set.seed(1234)
x1 <- rnorm(100, 5, 1)  # mean = 5, sd = 1
x2 <- rnorm(200, 10, 2) # mean = 10, sd = 2

# Theoretical SE for simple difference: 0.1732051
se_param(x1, x2, dif = "simple")

# Theoretical (Fieller, no covariance) SE for percent differences: 0.04
se_param(x1, x2, dif = "perc")
# }

Run the code above in your browser using DataLab